library(shiny)
library(wordcloud2)

ui <- fluidPage(
  mainPanel(
    wordcloud2Output("wordcloud")
  )
)

server <- function(input, output, session) {
  library(rtweet)
  library(tidytext)
  library(dplyr)
  source("twitter_keys.r")
  twitter_token <- create_token(
    app = "quantoid_scrape",
    consumer_key = key,
    consumer_secret = key_secret, 
    access_token = token, 
    access_secret = token_secret)
  rm(key, appname, key_secret, token, token_secret)
  
  rts <- reactive({
    invalidateLater(5000)
    search_tweets(q = "#rstats", n=100, include_rts=FALSE)
  })
  output$wordcloud <- renderWordcloud2({
    txts <- do.call("c", rts()$hashtags)
    texts <- data.frame(text = txts)
    freqs <- texts %>% 
      unnest_tokens(word, text)  %>% 
      mutate(word = tolower(word)) %>% 
      group_by(word) %>% 
      summarise(freq=n()) %>% 
      anti_join(get_stopwords())
      wordcloud2(freqs)
  })
  
  
  
}

shinyApp(ui, server)